mfyreport介绍

1、什么是mfyreport
mfyreport是基于unittest开发的的一个功能扩展库，关于mfyreport最初在开发的时候，在开发的过程中参考了木先生的代码。后续还会持续的扩展和开发一些新的功能，目前实现了以下功能：

HTML测试报告生成\
unittest数据驱动\
测试用例失败重运行\
多线程并发执行用例\
发送测试结果及报告到邮箱\
测试结果推送到钉钉\
测试结构推送到企业微信\

2、安装mfyreport\
mfyreport是基于python3.6开发的，安装前请确认你的python版本>3.6

安装命令\
pip install mfyreport